@@ -186,15 +186,18 @@ class Section(Entity, Mapping):
     def __getitem__(self, key):
         return self.__dict__.get(key)
 
-    def get_apartments(self, available_only=False):
+    def get_apartments(self, available_only=False, room_count=None):
         query = session.query(Apartment)\
                        .filter(apartments.c.project_title==self.project_title,
                                apartments.c.quarter_number==self.quarter_number,
                                apartments.c.building_number==self.building_number,
                                apartments.c.section_number==self.number)
+        apts = query.all()
         if available_only:
-            query = query.filter(apartments.c.status == 1)
-        return query.all()
+            apts = filter(lambda apt: apt.status is 1, apts)
+        if room_count is not None:
+            apts = filter(lambda apt: apt.room_count is room_count, apts)
+        return apts
 
     def get_floors(self, available_only=False):
         all_floors = session.query(Floor)\
